##  Automation 1: Subscription Is Added
Automation Configuration Parameter | Configuration
---|---
Trigger (When) |
  * Fact Sheet Type: Application
  * Event: Subscription Is Added
  * Select Subscription: Responsible - Application Owner


Conditions (If) | Configure optional conditions for the automation.
Actions (Then) | Run script: See the sample code provided below.


